.. include:: ../README.rst

Documentation
-------------

.. toctree::
   :maxdepth: 2

   abstract
   caching
   datastructures
   functional
   importing
   itools
   parallel

Additional Information
----------------------

.. toctree::
   :maxdepth: 2

   license
   changelog
